# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-06-28 14:54
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Country',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dts_insert', models.DateTimeField(auto_now_add=True)),
                ('dts_update', models.DateTimeField(blank=True, null=True)),
                ('dts_delete', models.DateTimeField(blank=True, null=True)),
                ('numeric', models.PositiveSmallIntegerField(unique=True)),
                ('code_2', models.CharField(max_length=2, unique=True)),
                ('code_3', models.CharField(max_length=3, unique=True)),
                ('iso3166', models.BooleanField(default=False)),
                ('obsolete', models.BooleanField(default=False)),
            ],
            options={
                'verbose_name_plural': 'Countries',
            },
        ),
        migrations.CreateModel(
            name='CountryName',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dts_insert', models.DateTimeField(auto_now_add=True)),
                ('dts_update', models.DateTimeField(blank=True, null=True)),
                ('dts_delete', models.DateTimeField(blank=True, null=True)),
                ('default', models.BooleanField(default=False)),
                ('value', models.CharField(max_length=64)),
                ('iso3166', models.BooleanField(default=False)),
                ('country', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_g11n.Country')),
            ],
            options={
                'verbose_name_plural': 'Country Names',
            },
        ),
        migrations.CreateModel(
            name='Currency',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dts_insert', models.DateTimeField(auto_now_add=True)),
                ('dts_update', models.DateTimeField(blank=True, null=True)),
                ('dts_delete', models.DateTimeField(blank=True, null=True)),
                ('country', models.TextField()),
                ('numeric', models.PositiveSmallIntegerField()),
                ('name', models.TextField()),
                ('code', models.TextField()),
                ('decimals', models.SmallIntegerField(blank=True, null=True)),
                ('is_fund', models.BooleanField(default=False)),
                ('default', models.BooleanField(default=True)),
                ('iso4217', models.BooleanField(default=False)),
                ('reference', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='django_g11n.Country')),
            ],
            options={
                'verbose_name_plural': 'Currencies',
            },
        ),
        migrations.CreateModel(
            name='IPRange',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dts_insert', models.DateTimeField(auto_now_add=True)),
                ('dts_update', models.DateTimeField(blank=True, null=True)),
                ('dts_delete', models.DateTimeField(blank=True, null=True)),
                ('identifier', models.TextField()),
                ('regional_nic', models.TextField()),
                ('tld', models.CharField(max_length=2)),
                ('ipv', models.PositiveSmallIntegerField()),
                ('network_hex', models.TextField(max_length=32)),
                ('broadcast_hex', models.TextField(max_length=32)),
                ('reference', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='django_g11n.Country')),
            ],
            options={
                'verbose_name_plural': 'IP Ranges',
            },
        ),
        migrations.CreateModel(
            name='Language',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dts_insert', models.DateTimeField(auto_now_add=True)),
                ('dts_update', models.DateTimeField(blank=True, null=True)),
                ('dts_delete', models.DateTimeField(blank=True, null=True)),
                ('bibliographic', models.CharField(blank=True, max_length=7, null=True)),
                ('terminologic', models.CharField(blank=True, max_length=3, null=True)),
                ('code_a2', models.CharField(blank=True, max_length=2, null=True)),
                ('english', models.TextField()),
                ('french', models.TextField()),
                ('iso639_2', models.BooleanField(default=False)),
                ('obsolete', models.BooleanField(default=False)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='LanguageCountry',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dts_insert', models.DateTimeField(auto_now_add=True)),
                ('dts_update', models.DateTimeField(blank=True, null=True)),
                ('dts_delete', models.DateTimeField(blank=True, null=True)),
                ('default', models.BooleanField(default=False)),
                ('override', models.BooleanField(default=True)),
                ('country', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_g11n.Country')),
                ('language', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_g11n.Language')),
            ],
            options={
                'verbose_name_plural': 'Language Countries',
            },
        ),
        migrations.CreateModel(
            name='LanguageCountrySpecifier',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dts_insert', models.DateTimeField(auto_now_add=True)),
                ('dts_update', models.DateTimeField(blank=True, null=True)),
                ('dts_delete', models.DateTimeField(blank=True, null=True)),
                ('short', models.CharField(max_length=2)),
                ('value', models.CharField(max_length=64)),
                ('override', models.BooleanField(default=True)),
            ],
            options={
                'verbose_name_plural': 'Language Country Specifiers',
            },
        ),
        migrations.AddField(
            model_name='languagecountry',
            name='specifier',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='django_g11n.LanguageCountrySpecifier'),
        ),
        migrations.AddField(
            model_name='countryname',
            name='language',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='django_g11n.LanguageCountry'),
        ),
    ]
