"""
Project information.
We use this module as __init__ is a generic module that django requires to be
specifically set up.
"""
LABELS = dict()
LABELS['class'] = 'G11N'
LABELS['name'] = 'django_g11n'
LABELS['verbose_name'] = 'Globalisation'
